summaryrefslogtreecommitdiff
path: root/src/pandoc.hs
diff options
context:
space:
mode:
authorJonas Smedegaard <dr@jones.dk>2012-05-24 10:31:18 +0200
committerJonas Smedegaard <dr@jones.dk>2012-05-24 10:31:18 +0200
commit61f8dd4da87bb4b8d536d81ea9430dad39cd975e (patch)
treedc5c683fee0b405016d6151f89aba0c98f11114c /src/pandoc.hs
parent9552543b96e2a994d84e4d2a1a17e15c0a953a29 (diff)
Add support for Slideous output.
Diffstat (limited to 'src/pandoc.hs')
-rw-r--r--src/pandoc.hs7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/pandoc.hs b/src/pandoc.hs
index 11ea88ec2..34d136aa8 100644
--- a/src/pandoc.hs
+++ b/src/pandoc.hs
@@ -101,7 +101,7 @@ data Opt = Opt
, optOutputFile :: String -- ^ Name of output file
, optNumberSections :: Bool -- ^ Number sections in LaTeX
, optSectionDivs :: Bool -- ^ Put sections in div tags in HTML
- , optIncremental :: Bool -- ^ Use incremental lists in Slidy/S5
+ , optIncremental :: Bool -- ^ Use incremental lists in Slidy/Slideous/S5
, optSelfContained :: Bool -- ^ Make HTML accessible offline
, optSmart :: Bool -- ^ Use smart typography
, optOldDashes :: Bool -- ^ Parse dashes like pandoc <=1.8.2.1
@@ -454,7 +454,7 @@ options =
, Option "i" ["incremental"]
(NoArg
(\opt -> return opt { optIncremental = True }))
- "" -- "Make list items display incrementally in Slidy/S5"
+ "" -- "Make list items display incrementally in Slidy/Slideous/S5"
, Option "" ["slide-level"]
(ReqArg
@@ -887,6 +887,7 @@ main = do
let slideVariant = case writerName' of
"s5" -> S5Slides
"slidy" -> SlidySlides
+ "slideous" -> SlideousSlides
"dzslides" -> DZSlides
_ -> NoSlides
@@ -1052,7 +1053,7 @@ main = do
where result = w writerOptions doc2 ++ ['\n' | not standalone']
htmlFormat = writerName' `elem`
["html","html+lhs","html5","html5+lhs",
- "s5","slidy","dzslides"]
+ "s5","slidy","slideous","dzslides"]
selfcontain = if selfContained && htmlFormat
then makeSelfContained datadir
else return